#ifndef MENRD_VARS_H
#define MENRD_VARS_H 1

#include <stdio.h>

/*  Output modes. Default (0) is ASCII text  */
#define MENRD_HTML   1
#define MENRD_GRAPH  2
#define MENRD_NVALS  4
#define MENRD_RAW    8
#define MENRD_STRIP 16
#define MENRD_TABLE 32
#define MENRD_UTF   64

/*
*	Location of data
*/
/*  Date and time  */
#define MENRD_DATE_POS 10
/*  Data  */
#define MENRD_DATA_POS 22
/*  Species  */
#define MENRD_SPECIES_POS 98	/*  3 digits  */
/*  Lines in graphs  */
#define MENRD_LINES_POS 109
/*  Graphs  */
#define MENRD_GRAPH_POS 149
/*  Minium total size  */
#define MENRD_MIN_SIZ 2453
/*  Number of blood vars. This includes padding  */
#define MENRD_BLD_VARS 20
/*  Config file  */
#define MENRD_CONF "/etc/menarini/vsight.conf"
//#define MENRD_CONF "vsight.conf"

/*  xtic positions and labels for gnuplot  */
#define MENRD_PLT_TCS_DOG "(\\\"0\\\" 0, \\\"5\\\" 55, \\\"10\\\" 110, \\\"15\\\" 165, \\\"20\\\" 220)"
#define MENRD_PLT_TCS_CAT "(\\\"0\\\" 0, \\\"5\\\" 60, \\\"10\\\" 120, \\\"15\\\" 180, \\\"20\\\" 240)"
#define MENRD_RBC_TCS "(\\\"0\\\" 0, \\\"50\\\" 55, \\\"150\\\" 160)"
#define MENRD_WBC_TCS "(\\\"0\\\" 0, \\\"50\\\" 45, \\\"150\\\" 140, \\\"250\\\" 225)"

/*  Colours  */
#define MENRD_BLACK  "000000"
#define MENRD_BROWN  "993300"
#define MENRD_RED    "FF0000"
#define MENRD_ORANGE "FF6600"
#define MENRD_YELLOW "FFCC00"
#define MENRD_GREEN  "00CC00"
#define MENRD_BLUE   "0066FF"
#define MENRD_VIOLET "6600FF"
#define MENRD_GRAY   "999999"
#define MENRD_PINK   "FF00CC"
#define MENRD_CYAN   "00FFCC"

/*  White blood cell count graph colour  */
#define MENRD_COL_WBC MENRD_BLUE
/*  Red blood cell count graph colour  */
#define MENRD_COL_RBC MENRD_RED
/*  Platelet count graph colour  */
#define MENRD_COL_PLT MENRD_GREEN

/*  Plot sizes  */
//#define MENRD_XSIZ 800
//#define MENRD_YSIZ 400
#define MENRD_XSIZ 512
#define MENRD_YSIZ 256

/*  Animal numbers. These are guessed!  */
enum {
	MENRD_DOG,
	MENRD_CAT,
	MENRD_HORSE,
	MENRD_RAT,
	MENRD_MOUSE,
	MENRD_RABBIT,
	MENRD_MONKEY,
	MENRD_COW,
	MENRD_PIG,
	MENRD_BUFFALO,
	MENRD_CAMEL,
	MENRD_SHEEP,
	MENRD_GOAT,
	MENRD_ANIMAL1,
	MENRD_ANIMAL2,
	MENRD_ANIMAL3,
	MENRD_UNKNOWN
};

char *menanimals[] = { \
	"Dog", 
	"Cat",
	"Horse",
	"Rat",
	"Mouse",
	"Rabbit",
	"Monkey",
	"Cow",
	"Pig",
	"Buffalo",
	"Camel",
	"Sheep",
	"Goat",
	"Animal1",
	"Animal2",
	"Animal3",
	"Unknown"
};

/*  First vars  */
struct mnhdvr {
	char *name;
	int len;
} menheadvars[] = { \
	{ "TxtDstCd", 1 },
	{ "ID",       8 },
	{ "Mode",     1 },
	{ "Month",    2 },
	{ "Day",      2 },
	{ "Year",     4 },
	{ "Hour",     2 },
	{ "Min",      2 },
	{ "",         0 }
};

/*  Total 10 + 12 = 22 bytes  */

/*  Blood vars; Haemoglobin g/dL to mmol/L is * 0.6202  */
struct mnbldvr {
	char *name;
	int  pad;
	int  len;
	double mult;
	int  decml;
	int  dcpad;
	/*  ASCII  */
	char *unita;
	int  pada;
	/*  UTF-8  */
	char *unitu;
	int  padu;
} menbldvars[] = { \
	/*
	*  Order matters!
	*
	*  U00B9, SUPERSCRIPT ONE:  \xc2\xb9
	*  U00B2, SUPERSCRIPT TWO:  \xc2\xb2
	*  U2079, SUPERSCRIPT NINE: \xe2\x81\xb9
	*
	*  Name     Pd  Ln  Mlt    Dc Dp   UnitA    Pa  UnitU              Pu
	*/
	{ "WBC",    4,  4,  0.1,   1, 4, "10^9/L",  3, "10\xe2\x81\xb9/L", 3 },
	{ "Lymph#", 1,  4,  0.1,   1, 4, "10^9/L",  3, "10\xe2\x81\xb9/L", 3 },
	{ "Mon#",   3,  4,  0.1,   1, 4, "10^9/L",  3, "10\xe2\x81\xb9/L", 3 },
	{ "Gran#",  2,  4,  0.1,   1, 4, "10^9/L",  3, "10\xe2\x81\xb9/L", 3 },
	{ "Lymph%", 1,  3,  0.1,   1, 4, "%",       8, "%",                7 },
	{ "Mon%",   3,  3,  0.1,   1, 4, "%",       8, "%",                7 },
	{ "Gran%",  2,  3,  0.1,   1, 4, "%",       8, "%",                7 },
	{ "RBC",    4,  4,  0.01,  2, 3, "10^12/L", 2, "10\xc2\xb9\xc2\xb2/L", 2 },
	/*  0.6202 * 0,1  */
	{ "HGB",    4,  3,  0.06202, 1, 4, "mmol/L", 3, "mmol/L",          2 },
	/*  0.6202 * 0,1  */
	{ "MCHC",   3,  4,  0.06202, 1, 4, "mmol/L", 3, "mmol/L",          2 },
	{ "MCV",    4,  4,  0.1,   1, 4, "fL",      7, "fL",               6 },
	/*  0.6202 * 0,01  */
	{ "MCH",    4,  4,  0.006202, 2, 3, "fmol", 5,   "fmol",           4 },
	{ "RDW",    4,  3,  0.1,   1, 4, "%",       8, "%",                7 },
	{ "HCT",    4,  3,  0.001, 3, 2, "L/L",     6, "L/L",              5 },
	{ "PLT",    4,  4,  1.0,   0, 6, "10^9/L",  3, "10\xe2\x81\xb9/L", 3 },
	{ "MPV",    4,  3,  0.1,   1, 4, "fL",      7, "fL",               6 },
	{ "PDW",    4,  3,  0.1,   1, 4, "fL",      7, "fL",               6 },
	{ "PCT",    4,  3,  0.001, 3, 2, "%",       8, "%",                7 },
	{ "Pad0",   3,  4,  0.0,   0, 0, "",        0, "",                 0 },
	{ "Eos%",   3,  3,  0.1,   1, 4, "%",       8, "%",                7 },
	{ "",       0,  0,  0.0,   0, 0, "",        9, "",                 0 }
};

/*  Space padding with lengts zero to ten  */
char *mnrpds[] = { "", " ", "  ", "   ", "    ", "     ", "      ", \
	"       ", "        ", "         ", "          " };

/*  ASCII or UTF-8 horizontal line  */
char hlin[256];
/*  Lengths in glyphs (not bytes)  */
#define MENRD_HL_A    27
#define MENRD_HL_U    26
/*  With min and max  */
#define MENRD_HL_NV_A 47
#define MENRD_HL_NV_U 46

/*
*    Blood variable minimum and maximum values
*    menanlims[Species][Blood-variable][Min-and-Max]
*/
double mnanlms[MENRD_UNKNOWN][MENRD_BLD_VARS][2];

/*  Total 22 + 70 = 92 bytes  */

/*  Other data  */
/*
Pad1       6
Species    3 <-- 92 + 6 = 98
pad2       8 <-- 98 + 3 + 8 = 109
GraphLn0  12
GraphLn1   6
GraphLn2   6
Pad3	  16 <-- 109 + 40 = 149
Graph0   768
Graph1   768
Graph2   768 <-- 2453 total
*/

#endif  /*  menvars.h  */

